@@ -1,6 +1,6 @@
 /*
  * VegaFusion
- * Copyright (C) 2022 Jon Mease
+ * Copyright (C) 2022 VegaFusion Technologies LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as
@@ -16,6 +16,7 @@
  * License along with this program.
  * If not, see http://www.gnu.org/licenses/.
  */
+use crate::data::table::VegaFusionTable;
 use crate::error::{Result, ResultWithContext, VegaFusionError};
 use crate::proto::gen::tasks::Task;
 use crate::spec::data::DataSpec;
@@ -131,8 +132,12 @@ impl ChartSpec {
         Ok(visitor.task_scope)
     }
 
-    pub fn to_tasks(&self, local_tz: &str) -> Result<Vec<Task>> {
-        let mut visitor = MakeTasksVisitor::new(local_tz);
+    pub fn to_tasks(
+        &self,
+        local_tz: &str,
+        inline_datasets: Option<HashMap<String, VegaFusionTable>>,
+    ) -> Result<Vec<Task>> {
+        let mut visitor = MakeTasksVisitor::new(local_tz, inline_datasets);
         self.walk(&mut visitor)?;
         Ok(visitor.tasks)
     }
