@@ -1,6 +1,6 @@
 /*
  * VegaFusion
- * Copyright (C) 2022 Jon Mease
+ * Copyright (C) 2022 VegaFusion Technologies LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as
@@ -36,9 +36,9 @@ use vegafusion_core::transform::aggregate::op_name;
 impl TransformTrait for JoinAggregate {
     async fn eval(
         &self,
-        dataframe: Arc<dyn DataFrame>,
+        dataframe: Arc<DataFrame>,
         _config: &CompilationConfig,
-    ) -> Result<(Arc<dyn DataFrame>, Vec<TaskValue>)> {
+    ) -> Result<(Arc<DataFrame>, Vec<TaskValue>)> {
         let mut agg_exprs = Vec::new();
         let mut agg_cols = Vec::new();
         for (i, (field, op)) in self.fields.iter().zip(self.ops.iter()).enumerate() {
@@ -120,14 +120,12 @@ impl TransformTrait for JoinAggregate {
             let dataframe =
                 dataframe.select(vec![Expr::Wildcard, lit(true).alias("__unit_lhs")])?;
 
-            let dataframe = dataframe.join(
+            dataframe.join(
                 grouped_dataframe,
                 JoinType::Inner,
                 &["__unit_rhs"],
                 &["__unit_lhs"],
-            )?;
-
-            dataframe
+            )?
         } else {
             let grouped_dataframe = dataframe
                 .aggregate(group_exprs, agg_exprs)
