@@ -67,7 +67,7 @@ async fn test_extract_server_data() {
     let client_stubs: Vec<_> = client_inputs.difference(&client_defs).collect();
     println!("client_stubs: {:?}", client_stubs);
 
-    let tasks = server_spec.to_tasks(local_tz).unwrap();
+    let tasks = server_spec.to_tasks(local_tz, None).unwrap();
     let graph = Arc::new(TaskGraph::new(tasks, &task_scope).unwrap());
     let mapping = graph.build_mapping();
     // println!("{:#?}", mapping);
