@@ -38,3 +38,25 @@ pub fn vega_json_dataset(name: &str) -> VegaFusionTable {
 
     VegaFusionTable::from_json(&json_value, 1024).unwrap()
 }
+
+pub async fn vega_json_dataset_async(name: &str) -> VegaFusionTable {
+    // Remove trailing .json if present because we'll add it below
+    let name = match name.strip_suffix(".json") {
+        None => name,
+        Some(name) => name,
+    };
+
+    // Fetch dataset from vega-datasets repository
+    let body = reqwest::get(format!(
+        "https://raw.githubusercontent.com/vega/vega-datasets/master/data/{}.json",
+        name
+    ))
+    .await
+    .unwrap()
+    .text()
+    .await
+    .unwrap();
+    let json_value: Value = serde_json::from_str(&body).unwrap();
+
+    VegaFusionTable::from_json(&json_value, 1024).unwrap()
+}
